
# q-expansion of newform 476.4.a.b, downloaded from the LMFDB on 14 January 2025.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 476
weight = 4
poly_data = [-720, 268, 547, -32, -71, -2, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0], 1], [[-2466, 782, 217, 99, 5, -2], 243], [[-3123, -1511, 26, -99, -5, 2], 243], [[-252, -4975, 61, 936, 35, -14], 243], [[900, -329, -274, 54, 7, -1], 27]]

hecke_ring_character_values = None
aps_data = [[0, 0, 0, 0, 0, 0], [0, 1, 0, 0, 0, 0], [-2, 0, 0, 0, -1, 0], [-7, 0, 0, 0, 0, 0], [-1, 1, 2, -1, -1, 0], [0, 6, -1, 0, -1, -1], [17, 0, 0, 0, 0, 0], [30, 4, -5, 0, -4, 2], [14, 6, 3, 4, 0, -6], [43, 9, 6, -7, -5, 4], [57, 27, -3, -5, -5, -3], [83, 11, -1, 3, 12, 5], [29, 12, 16, -1, -3, -8], [19, -14, 9, 5, 0, -13], [184, -24, -6, 4, -11, 11], [93, -17, -9, 5, 24, -10], [158, -38, 6, -18, -20, 2], [86, -11, -10, 0, -11, -17], [243, -53, 0, 7, 12, -6], [212, -82, 13, -10, -36, 8], [37, -6, 4, 7, -5, -18], [260, -104, 10, 0, 19, 1], [46, 8, -11, -4, -19, -7], [-52, -108, -6, -10, -57, -3], [-279, 109, -2, -13, -43, -29], [208, 14, 17, 20, 10, 58], [408, 74, 73, -6, -29, -3], [103, -73, -21, 25, 21, 18], [379, -21, 26, 1, 72, 43], [-448, 16, -40, -18, 7, -11], [109, -107, -18, -7, 30, -56], [151, -111, 6, 39, -88, -7], [-205, 226, 5, 39, 51, -34], [40, 176, -5, -46, 15, 38], [-393, -174, 71, -5, 15, -98], [587, 126, -23, 25, 178, -31], [-1028, -6, 82, -6, -79, -13], [371, -179, -71, -127, 13, 100], [-841, 134, -80, 11, 98, 27], [-112, 75, 0, 30, -9, -113], [575, -248, 37, 57, -10, -39], [-919, 181, -20, -61, 18, 19], [-251, -83, 28, 61, -114, -14], [-78, -156, 21, 26, -169, 49], [-1281, -55, 53, 75, 19, -6], [113, 8, 86, 65, -166, -7], [-83, -387, 52, 41, 20, -89], [-68, 354, 3, 34, 60, -156], [-1708, -228, -165, 38, -33, -42], [588, -416, -26, 66, 143, -93], [-1400, -248, -37, -124, -236, 82], [-1019, 232, 95, -121, 144, 5], [21, 393, -76, 75, -103, -1], [-596, -538, 193, 34, 274, 42], [-1074, -528, 53, 30, 296, 76], [2086, -30, -146, -182, 18, 112], [-2781, -569, 68, -27, 286, 69], [3270, 34, 17, -80, 126, 68], [-141, -59, -93, 67, -22, -129], [-503, 35, 411, 29, 76, -92], [1900, 768, -133, -106, 9, 10], [-1328, -222, -157, -40, 54, 268], [-60, 560, 25, 50, 307, -17], [-2737, 701, -39, -223, -205, 33], [57, -699, -62, 131, 317, -141], [1501, 245, 415, 21, 220, -51], [4305, 5, -54, 225, 14, 4], [-2122, 926, 364, 100, 212, -74], [2501, -471, 72, 289, 142, -29], [2942, -550, -25, -90, -391, -33], [-342, -870, -202, 148, -107, -37], [-525, 271, 366, -41, -204, 168], [1481, 704, -318, -87, 122, 253], [3211, -140, -207, -69, 161, -60], [95, -295, 36, 83, -51, -206], [4952, 188, -126, -172, -53, -41], [7127, 349, -179, -85, -108, -116], [2312, -1174, 324, -278, -85, 22], [18, 458, 49, -206, 48, 204], [-2472, -482, -568, 158, 32, -48], [942, -1018, 91, -96, 329, 52], [3027, -580, -441, -49, -19, 116], [3994, -1282, -207, -116, 391, -163], [108, -126, -66, 494, 209, 17], [4743, -136, -312, 291, -4, 193], [-742, 1242, 4, -50, 178, -240], [-3378, -430, -343, -42, 665, -43], [5025, 863, 465, -79, -322, -122], [-2664, -970, -78, 118, 351, -457], [843, -246, 167, 301, 304, 407], [3566, -44, 118, -202, -443, -185], [483, 284, 6, 179, 206, 323], [12346, 190, -7, 100, 29, 19], [-639, 477, -518, 81, 492, 8], [2835, -691, -161, -147, -249, -184], [-2713, 437, 893, 193, 167, -89], [4938, -1102, 171, 218, -65, -5], [-1433, -216, -308, 25, -665, 148], [3902, -378, 491, 336, 90, -332], [3385, 2039, -191, 109, -26, -415], [1229, 305, 226, -179, -269, -364], [5756, -354, 204, -194, 40, 134], [-5490, 1038, -296, -126, -559, 299], [4623, -1382, -155, -461, -5, 230], [4423, 123, 55, 185, 446, -293], [-6204, 8, -85, -288, 735, -23], [1410, -1292, -716, -178, -199, 35], [-664, 1326, 55, 284, -988, -116], [-2679, 386, -295, 239, 780, -179], [-7200, 722, 250, 378, 232, 102], [2575, -779, -631, -471, 283, 153], [987, 2093, 323, -21, -366, -2], [-12614, 2594, -92, 472, 211, 101], [-1233, 509, 1184, 395, 646, -217], [-3135, 581, -564, 577, -198, -114], [-3724, 1520, 639, -168, 701, -199], [-7082, 313, -708, -410, -642, -24], [-14994, 1934, -202, 250, -705, 13], [-357, -325, 176, -419, -916, -533], [-807, 493, 940, 85, -488, -20], [2004, 76, 1227, -604, -204, 14], [-1362, 1284, -340, -676, -183, 227], [-7707, -1515, 196, 63, 56, 313], [2797, 1395, 417, 99, 343, -196], [4416, 1393, -888, -256, 306, -90], [-2588, -194, -334, -94, -260, -330], [10201, 1229, -509, 25, 1145, -124], [-11387, -1956, -230, 389, 190, -835], [194, 1230, -553, -88, -1339, -165], [5824, -846, 278, -42, -417, 699], [14231, -828, -435, 497, 10, 125], [-9614, -2426, -152, 74, 442, 794], [7272, 650, -995, 2, -268, 860], [12901, -634, 345, 597, 1785, -602], [-4432, -584, -600, -34, -496, -138], [-1230, 924, 624, -1032, -1007, -95], [9134, -782, -650, -28, -683, 793], [-7677, 873, 988, 111, 184, 237], [8686, -1128, -859, 394, -345, 787], [-4334, -5310, -361, 62, 457, 837], [-882, 1977, 1824, 494, 1148, -218], [1231, -633, 717, 507, -458, 491], [-844, 4832, -650, 184, -754, -196], [-7909, -399, 873, -159, -563, 286], [17230, -1240, -725, -298, -553, -99], [-4816, 3812, 1266, 124, -392, -88], [23831, -37, 590, 309, -324, -721], [-13201, -1509, 592, 101, -807, 527], [24308, -376, 562, 180, 767, -147], [6897, 3045, 136, 289, -682, -608], [8265, -2197, -279, 453, -1751, -198], [-6523, 613, -186, -1265, 117, -307], [11301, 1457, -1140, 801, -1582, -128], [2127, -2055, 137, -623, -663, -599], [-6525, 111, 372, -569, -1124, 655], [4094, -2262, -3, -528, 2226, -142], [-897, -272, -753, -351, 370, 929], [11115, -2673, 24, -679, 45, 327], [-1402, 646, -550, -1720, -380, 826], [-1338, 1765, -1222, 392, 1413, -473], [-13327, -69, -400, 613, 47, -1022], [-10585, -5187, 435, 923, -822, -618], [12541, -36, -981, 1711, 1930, -61], [518, 3262, 1666, 470, 1331, -23], [-2275, 2275, 397, 1501, 124, -944], [-7753, -467, 423, 501, -1779, -819], [-7506, -3532, 1618, -390, -258, 134], [6490, 1125, 334, 1100, -603, -517], [12500, 2416, 1558, 54, 1436, -308], [688, -5119, -212, -122, -947, 133], [152, 2812, -956, 92, -30, 86], [-1798, -4382, 442, 696, 1288, 522], [6942, -260, 392, 206, 634, 1272], [3637, 2263, 1517, -499, -2526, 382], [24650, -784, 631, 256, -1587, -1], [4147, 459, -996, -95, 1245, 1173], [5193, -1871, -372, -1219, -480, 2123], [-8501, 3043, 26, 209, 3127, 876], [23012, -5014, -405, -1462, -261, 339], [1788, -5252, 97, 136, -1297, -641], [-5210, 2050, 538, -326, 764, -702], [13074, -1077, 54, 1182, -1546, -732], [-3289, -3087, 856, -1663, -969, 742], [8238, 1784, -785, 842, -2390, 294], [3857, -1191, 1262, 493, 782, -1596], [1454, 1194, 1059, -34, -1234, 572], [-25709, 3917, -293, -541, -363, 1092], [3486, -4630, -496, 410, 1276, -736], [-4812, -1168, -1696, 538, -557, 279], [-5368, -868, -846, -292, -1546, 934], [-34915, -1326, 1592, 335, 241, -280], [-2433, 559, -323, 93, 2842, -693], [-1232, 2456, 1070, -240, 1388, -424], [15142, -6002, 897, 258, -63, -271], [-30383, -3351, 1591, 179, -647, 216], [14501, -8443, -484, 515, 1657, 829], [-11442, -5536, -2301, 322, -531, 313], [-957, -1125, -1610, -663, -2959, 566], [5059, 4002, 1586, 209, -1309, -168], [-4246, -6670, 213, -812, 2734, 954], [-19957, -997, -1379, 775, 2747, -40], [-7017, 681, 1247, 1469, -945, 563], [-30696, -926, -1435, -436, -1327, 171], [11536, 4880, -470, -1710, -813, 1193], [-2302, 3360, -1134, -166, 2757, -97], [-24778, 2210, 1323, -530, -126, 70], [-7102, -1082, 401, -516, 1150, 214], [95, 2104, 1291, 773, 1748, 39], [-7634, -3806, 79, 2322, 1370, 24], [21972, 770, -264, 928, -932, 302], [-43972, 1052, -789, 280, -639, 69], [36412, 342, 318, -1006, -2232, -794], [-320, 538, 940, -384, -2413, -639], [-6898, -2210, 918, -770, 1490, 94], [6259, -2398, 2696, -297, -1196, -87], [-39083, 1924, 2432, 199, 811, -1102], [-16774, 186, -1802, -170, 1684, 1958], [-5750, -4238, -335, -774, -632, 1894], [-43646, 1582, -308, -1854, -746, 1190], [12659, -687, -99, 943, 4398, -628], [-21817, 8669, -783, 1123, -748, -564], [-17137, -1222, -262, -601, -2756, -27], [9781, 2142, -319, 545, -689, -8], [-12448, -4888, 541, -78, 396, 2272], [-6496, -4742, 1630, -80, 1744, -384], [-3365, 2409, 715, 347, -4050, 256], [-22176, -6302, 1880, -490, -3514, 1548], [5348, -5568, 626, 664, 3918, 328], [-20798, -3428, -1825, 376, -4046, -584], [-14993, 965, -1404, 267, 1132, 1379], [-25699, -4232, 3415, -583, -171, -1838], [24689, 1663, -2294, 361, 2042, -471], [50420, -3668, -198, -1256, 1292, 8], [-55517, -1094, 2217, 159, -143, -652], [-13248, -5798, -609, 90, 603, 527], [11000, 5296, 2286, 1340, -2071, -1061], [-52258, -3004, -900, -716, -1218, 174], [34275, 2817, -303, 279, 401, 2392], [-5415, -5875, 503, -989, 2461, -982], [20698, -3452, 2763, -592, -1333, 323], [22669, -3801, -2496, 145, -479, 2504], [-31712, 1782, 640, 108, 3438, 280], [36132, -8088, -136, -436, -2050, 1688], [-10105, 7334, -37, 667, -1661, 190], [16237, 3481, -2650, 327, -439, -235], [48121, -2273, -1501, 719, 713, -357], [14381, -11150, -746, 653, 480, -829], [33616, 2279, 376, -1224, 3750, 1234], [40443, -589, -92, 863, 950, 1204], [4575, 1856, -1251, 245, 1896, -817], [-9489, -5670, 793, 1407, -3279, -100], [13229, 2993, -1120, 811, -2393, -929], [-15995, -6395, 388, 965, 402, 1796], [15641, -3951, -312, -977, 333, -1323], [15084, 694, -928, 1374, 2682, -1032], [-18817, 10154, 661, -319, 18, -1679], [-28921, -13919, -1226, 1365, 1144, -145], [29348, -2368, 2587, -1058, -3147, -1302], [-358, -1739, 1792, -1008, 1847, 721], [-53046, -1904, -1190, -260, 4137, 2229], [-6854, 7730, 177, -1444, 2693, 221], [3881, -275, 172, -283, -3598, 2114], [28846, 9756, 3072, -544, -1941, -2194], [-12770, -3684, -3962, -460, -483, -642], [-34645, 3404, 168, -1427, 615, 1400], [22320, -344, 821, 366, 3650, -1164], [55549, -6825, -1335, 1601, 50, 860], [50678, -6956, 824, 660, 755, -1773], [16037, 12049, 1845, 1923, 1332, -3699], [10701, -1554, 67, 1601, -3933, 1484], [-42640, -1682, -180, -142, -1617, 2456], [7064, 8964, -88, -116, 2722, -1270], [-18858, -3954, -71, 902, -1991, 427], [9799, 4463, -2498, 3347, 132, -1460], [-25518, 2262, 137, 2274, 700, -3742], [-1460, 6680, 81, -506, -3107, -629], [-22415, -6766, -955, -1917, 1314, 2491], [-29623, 17531, 1427, -2031, -2684, 366], [19857, -6406, -2211, -483, 3961, -798], [50678, -3344, 2601, -2124, -1048, 2024], [9970, -14572, -1352, 234, -2358, -354], [3226, 2080, 642, 2454, 4709, -993], [11068, 5284, -1640, -460, 4902, -190], [13824, 2676, -5444, -1590, 1158, 2264], [-20474, -3002, 433, 396, 3665, -960], [10333, 18458, -1611, -765, -4650, -1001], [-14288, 12354, -719, 1352, 1526, -788], [-36469, -2133, 1264, -91, 2180, -3287], [58586, -2260, 2622, -1506, 3003, 2597], [-274, -18, 4443, 2226, 1146, -2188], [725, -5423, -6911, 81, 890, 741], [10114, 942, 5127, 1068, 2095, -1428], [40082, 1096, -1714, 132, -2660, 2256], [-4420, 6496, 445, 2202, 1231, -3344], [24849, 1745, -1891, -2499, 1257, 3114], [-5420, 12603, -2202, 894, 175, 1019], [-20396, 1802, 5428, 1156, -762, -2256], [39240, -2758, -818, 1822, -2410, 2382], [-2376, 2776, -6059, 886, -2537, 1642], [-10178, 19568, 794, -1586, -537, -77], [-7010, 11690, -86, -992, 5658, -8], [44102, 1756, 2472, 1776, 886, -1890], [30460, -9172, 4818, -184, -1759, -4399], [-32163, -6331, -1915, 3203, 3046, -791], [-78937, 2153, -743, -643, -1105, -2740], [2546, -2948, -3470, -1684, -6843, -909], [-26127, 16889, 1082, -1231, 318, 1822], [-434, 10653, 604, -2732, -6257, 729], [-37139, -9615, 3964, -1347, 3044, 342], [-27885, 2282, 1671, -3689, -3229, -2638], [54495, -16823, -2167, 345, 183, 451], [-28497, 5719, -4691, 1651, 3269, 1264], [30112, -560, 3205, 4056, 1872, -1428], [1169, 656, -3137, 2311, 3330, -3609], [-26691, -13742, 287, 1583, 1766, 1879], [-27430, 14818, 1057, 1858, 2168, -686], [5284, 1986, -2948, -3784, 5857, 731], [-10554, 25658, 677, -1552, 765, -239], [-16587, 21470, 3962, -117, 153, -1896], [34750, -9620, 2952, -932, 4742, -478], [3882, 3851, -2682, -3098, 1686, -1160], [-48010, -1842, -3732, 644, 6501, 1253], [23174, 2720, 6021, 4194, -2259, -1869], [-5963, 9621, -2102, 585, -2130, -148], [62256, -7266, 957, -960, 1047, 2733], [-64360, 4524, -2138, -3510, -2796, 1354], [-68695, -4235, 3016, -299, -867, 2326], [-40294, -20562, -547, -760, -3453, 3280], [19794, 6780, 3362, -2242, -5670, 2514], [31303, 6457, -4980, 49, 254, 1897], [14141, 569, 3130, 1275, 1305, 1328], [-34859, -3061, -1255, 1921, -417, -3250], [27313, -4696, -2666, 1433, 6514, -3423], [-7510, -8196, -5243, 2936, 3057, -529], [25015, 2267, -3750, -3153, -1739, 1878], [-84503, -1209, 912, 1093, 6436, 1679], [23881, -2100, 1697, 6025, 3523, 688], [28541, 21734, 654, -1317, -2199, -2204], [-26703, -3966, -5256, 667, 3233, 3004], [13590, -6468, 2238, -3206, -8294, 998], [-25397, -984, 65, -2069, 4389, -288], [-39147, -1805, -5321, -319, 196, 3984], [2113, 14829, -426, -497, 190, -1993], [-52179, 2489, -4020, 2637, -3842, -2656], [81789, -300, 2785, 749, 6223, -188], [-15033, 13233, -897, -2359, -6234, -3111], [-100140, 27838, 2258, 2474, 2981, -2292], [-4615, 8809, 412, -1587, -5570, 3516], [20261, -3317, -2405, -2653, 75, 5437], [-52966, 3777, -746, -900, 1953, -633], [-15530, -7426, 4275, -2064, -3716, -586], [8606, -3484, 3317, 2878, -5565, -2487], [-84733, -9378, -1529, 1423, -2351, -388], [-29025, -1323, -443, 961, -3471, 2391], [-28143, 11915, -91, -6219, -2722, 314], [19836, 2072, 2986, -1962, -1807, -3113], [51274, 8300, 2271, -920, 1100, 1404], [9778, 7165, 3662, -2418, 2302, 1220], [43164, 18458, -902, 1078, 2787, -307], [-87554, -5162, 3336, -2714, 5648, -118], [22539, -9735, -2736, 677, -3863, 284], [63291, 6095, 3816, 2689, 1665, -543], [15739, -18609, 2142, 919, -406, 2142], [-57679, 4093, -2812, 2405, 2536, -3623], [64018, -3762, 169, 7520, 813, -1871], [-2931, -22937, -221, 1169, -1390, -462], [-5088, 8223, -3712, -2290, 4825, 1993], [-18155, 16780, 4027, 71, 6382, -41], [86750, 11654, 1453, -58, -1825, -649], [62601, -8758, 2721, 907, 4578, -1385], [-330, -11071, 3152, 2598, -3208, -4994], [31216, -9100, -2548, 304, -2955, 3359], [-10045, -11096, 2761, -1725, -8641, -294], [66134, 9416, 6183, -2236, -1731, 985], [40999, 5845, -1253, -1057, 2606, 4639], [-2062, -4479, 4000, 266, 7400, -50], [-61226, -7258, 8727, 1380, 1067, -2089], [-67252, -14670, 4580, -2486, 5675, 1227], [54814, 5018, -722, 6096, -5144, -1630], [5142, 3976, -3945, -5430, 1881, 3929], [-44672, 8471, -1646, -190, 6563, -4509], [-11482, 29468, -258, -2104, -3972, -2940], [49308, -13158, -2971, 3126, 7995, -1677], [67036, -14726, -2484, -286, 758, -1506], [14848, -20121, -5110, -852, 3530, 3542], [-72108, -18848, -3166, -432, 5136, 5912], [130202, 2986, 2812, 1522, -184, -94], [-13226, 12340, 3098, 1492, 3920, -234], [-17599, -7105, -377, -1861, 4456, -4827], [17172, -18770, -3601, -190, -1512, 282], [32150, -218, 4490, 3520, -1868, -4430], [2149, -11215, 3062, -173, -6580, -3235], [92703, -6113, -2186, 2663, 5462, 114], [57924, 7664, -245, 326, -6143, 2281], [-21437, 8191, -360, -1989, 6786, 420], [46024, -15492, -1631, 3640, 1977, 4169], [37394, 264, 4760, -6494, -6881, -297], [-38294, 2302, 1899, -1930, -9508, 778], [-7193, 7625, -281, 1057, 2832, 1409], [33419, 30989, -1215, 151, -2954, -4016], [76989, -13579, -1508, -3489, 1938, 1527], [157195, -15763, -449, -1745, 1304, 684], [20945, -14442, -1815, -2401, -5340, 405], [54639, -3024, 3878, 3605, 4903, -3600], [21586, -16252, 3438, -1864, 7250, 2176], [-17648, 19800, 4040, -2808, -6732, 4156], [-33607, -2889, -431, 861, 3758, 282], [-11639, -15558, 2481, 5301, 77, -2850], [74178, 9356, -6254, -4870, 2370, 1090], [74580, -7015, -2180, 828, 3300, -3880], [-18313, -5041, -3158, -807, 1475, 6623], [56799, 7253, -1075, -557, -1982, -1142], [2667, 14931, -9136, 967, -4300, 1632], [35565, 24903, -7140, 3009, 4894, -1363], [68497, 1310, 6745, -43, 2769, -4174], [96680, -13871, 5230, 1258, 3433, -3027], [17446, -22798, 4433, -3896, 3173, 3251], [41515, 981, -1425, 4313, 5189, -2537], [61293, -33227, -1662, -2673, -2909, 4005], [1138, 21596, 2156, -1982, 3587, 1283], [52545, 6544, -2885, 3381, 4875, 4528], [-34154, -9725, 4028, -2756, -6195, 3155], [-102670, 564, -1287, 148, -5796, -1444], [-49464, 8852, 4041, 6102, -2938, -1074], [37846, -11008, 1190, 1096, -4268, 4236], [-12776, 17142, 4404, 3178, -6143, -873], [21773, 2943, 557, -1101, -11507, 1272], [-34186, 7034, -6914, -504, -1715, 1679], [7644, 15362, 7348, -48, -4952, -1228], [-21995, -8513, -4237, -1461, 599, -4275]]
